@@ -326,6 +326,8 @@ create_cluster_context(zend_class_entry *class_type TSRMLS_DC) {
 
     zend_hash_copy(cluster->std.properties, &class_type->default_properties,
         (copy_ctor_func_t)zval_add_ref, (void*)&tmp, sizeof(zval*));
+#else
+    object_properties_init(&cluster->std, class_type);
 #endif
 
     retval.handle = zend_objects_store_put(cluster,
@@ -506,7 +508,7 @@ PHP_METHOD(RedisCluster, __construct) {
 
     // Parse arguments
     if(zend_parse_method_parameters(ZEND_NUM_ARGS() TSRMLS_CC, getThis(),
-                                    "Os|addb", &object, redis_cluster_ce, &name,
+                                    "Os!|addb", &object, redis_cluster_ce, &name,
                                     &name_len, &z_seeds, &timeout,
                                     &read_timeout, &persistent)==FAILURE)
     {
